#
# spec file for package forge
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           forge
%define libname libforge
Summary:        High Performance Visualization Library
License:        BSD-3-Clause
Group:          Productivity/Scientific/Other
Version:        3.2.2
Release:        7.8
Url:            https://github.com/arrayfire/forge
Source:         https://github.com/arrayfire/forge/archive/af%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  doxygen
BuildRequires:  glm-devel
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glewmx)
BuildRequires:  pkgconfig(glfw3)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkg-config
Requires:       %{libname}%{sonum} = %{version}

%description
A prototype of the OpenGL interop library that can be used with
ArrayFire. The goal of Forge is to provide high performance OpenGL
visualizations for C/C++ applications that use CUDA/OpenCL. Forge
uses OpenGL >=3.3 forward compatible contexts, so please make sure
you have capable hardware before trying it out.

%package devel
Summary:        High Performance Visualization Library
Group:          Development/Libraries/C and C++
Requires:       cmake
Requires:       glm-devel
Requires:       pkgconfig(fontconfig)
Requires:       pkgconfig(freetype2)
Requires:       pkgconfig(glew)
Requires:       pkgconfig(glewmx)
Requires:       pkgconfig(glfw3)
Requires:       pkgconfig(sdl2)

%description devel
A prototype of the OpenGL interop library that can be used with
ArrayFire. The goal of Forge is to provide high performance OpenGL
visualizations for C/C++ applications that use CUDA/OpenCL. Forge
uses OpenGL >=3.3 forward compatible contexts, so please make sure
you have capable hardware before trying it out.

This package provides the development files and headers needed to
build packages using Forge.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
Recommends:     %{name}-devel = %{version}

%description doc
A prototype of the OpenGL interop library that can be used with
ArrayFire. The goal of Forge is to provide high performance OpenGL
visualizations for C/C++ applications that use CUDA/OpenCL. Forge
uses OpenGL >=3.3 forward compatible contexts, so please make sure
you have capable hardware before trying it out.

This package provides the documentation and help files for Forge.

%prep
%setup -q -n forge-af%{version}

%build
%cmake \
    -DCMAKE_CXX_FLAGS="%{optflags}" \
    -DBUILD_DOCUMENTATION=ON \
    -DUSE_LOCAL_GLM=OFF \
    -DUSE_LOCAL_FREETYPE=OFF \
    -DFG_INSTALL_LIB_DIR=%{_libdir} \
    -DFG_INSTALL_CMAKE_DIR=%{_libdir}/cmake/Forge/ \
    -DFG_INSTALL_DOC_DIR=%{_docdir}/%{name}/ \
    -DFG_INSTALL_EXAMPLE_DIR=%{_docdir}/%{name}/examples

make %{?_smp_mflags}

%install
%cmake_install

%check
%ctest

%files devel
%defattr(-,root,root,-)
%doc LICENSE README.md
%{_libdir}/libforge.so
%{_libdir}/cmake/Forge/
%{_includedir}/*Copy.hpp
%{_includedir}/forge.h
%{_includedir}/fg/

%files doc
%defattr(-,root,root,-)
%doc LICENSE README.md
%dir %{_docdir}/%{name}/
%{_docdir}/%{name}/html/
%{_docdir}/%{name}/examples/


%changelog
* Thu Sep 15 2016 toddrme2178@gmail.com
- Make glm buildrequires more general.
* Tue Aug  2 2016 toddrme2178@gmail.com
- Initial version
